@@ -8,7 +8,7 @@ use Mojo::Redis::Cursor;
 use Mojo::Redis::Database;
 use Mojo::Redis::PubSub;
 
-our $VERSION = '3.17';
+our $VERSION = '3.18';
 
 $ENV{MOJO_REDIS_URL} ||= 'redis://localhost:6379';
 
@@ -16,9 +16,7 @@ has encoding        => 'UTF-8';
 has max_connections => 5;
 
 has protocol_class => do {
-  my $class = $ENV{MOJO_REDIS_PROTOCOL};
-  $class ||= eval q(require Protocol::Redis::XS; 'Protocol::Redis::XS');
-  $class ||= 'Protocol::Redis';
+  my $class = $ENV{MOJO_REDIS_PROTOCOL} || 'Protocol::Redis';
   eval "require $class; 1" or die $@;
   $class;
 };
@@ -149,11 +147,40 @@ L<https://github.com/jhthorsen/mojo-redis/issues> if you find this module
 useful, annoying or if you simply find bugs. Feedback can also be sent to
 C<jhthorsen@cpan.org>.
 
+=head1 CAVEATS
+
+L<Protocol::Redis::XS> is not the default L</protocol> because it has some
+limitations:
+
+=over 2
+
+=item * Cannot handle binary data
+
+L<Mojo::Redis::Cache> uses L<Protocol::Redis> for now, since
+L<Protocol::Redis::XS> fail to handle binary data.
+
+See L<https://github.com/dgl/protocol-redis-xs/issues/4> for more information.
+
+=item * Cannot handle multi bulk replies with depth higher than 2
+
+L<Mojo::Redis::Database/xread> and other Redis commands returns complex nested
+data structures with depth higher than two. L<Protocol::Redis::XS> is unable to
+handle these messages.
+
+See L<https://github.com/dgl/protocol-redis-xs/issues/5> for more information.
+
+=back
+
+If you experience any issues with L<Protocol::Redis::XS> then please report
+them to L<https://github.com/dgl/protocol-redis-xs/issues>. It is still the
+default L</protocol> though, since it is a lot faster than L<Protocol::Redis>
+for most tasks.
+
 =head1 EVENTS
 
 =head2 connection
 
-  $cb = $self->on(connection => sub { my ($self, $connection) = @_; });
+  $cb = $redis->on(connection => sub { my ($redis, $connection) = @_; });
 
 Emitted when L<Mojo::Redis::Connection> connects to the Redis.
 
@@ -161,8 +188,8 @@ Emitted when L<Mojo::Redis::Connection> connects to the Redis.
 
 =head2 encoding
 
-  $str  = $self->encoding;
-  $self = $self->encoding("UTF-8");
+  $str   = $redis->encoding;
+  $redis = $redis->encoding("UTF-8");
 
 The value of this attribute will be passed on to
 L<Mojo::Redis::Connection/encoding> when a new connection is created. This
@@ -173,31 +200,32 @@ Default value is "UTF-8".
 
 =head2 max_connections
 
-  $int = $self->max_connections;
-  $self = $self->max_connections(5);
+  $int   = $redis->max_connections;
+  $redis = $redis->max_connections(5);
 
 Maximum number of idle database handles to cache for future use, defaults to
 5. (Default is subject to change)
 
 =head2 protocol_class
 
-  $str = $self->protocol_class;
-  $self = $self->protocol_class("Protocol::Redis::XS");
+  $str   = $redis->protocol_class;
+  $redis = $redis->protocol_class("Protocol::Redis::XS");
 
-Default to L<Protocol::Redis::XS> if the optional module is available, or
-falls back to L<Protocol::Redis>.
+Default to L<Protocol::Redis>. This will be changed in the future, if we see a
+more stable version of an alternative to L<Protocol::Redis::XS>.  See
+L</CAVEATS> for details.
 
 =head2 pubsub
 
-  $pubsub = $self->pubsub;
+  $pubsub = $redis->pubsub;
 
 Lazy builds an instance of L<Mojo::Redis::PubSub> for this object, instead of
 returning a new instance like L</db> does.
 
 =head2 url
 
-  $url = $self->url;
-  $self = $self->url(Mojo::URL->new("redis://localhost/3"));
+  $url   = $redis->url;
+  $redis = $redis->url(Mojo::URL->new("redis://localhost/3"));
 
 Holds an instance of L<Mojo::URL> that describes how to connect to the Redis server.
 
@@ -205,19 +233,19 @@ Holds an instance of L<Mojo::URL> that describes how to connect to the Redis ser
 
 =head2 db
 
-  $db = $self->db;
+  $db = $redis->db;
 
 Returns an instance of L<Mojo::Redis::Database>.
 
 =head2 cache
 
-  $cache = $self->cache(%attrs);
+  $cache = $redis->cache(%attrs);
 
 Returns an instance of L<Mojo::Redis::Cache>.
 
 =head2 cursor
 
-  $cursor = $self->cursor(@command);
+  $cursor = $redis->cursor(@command);
 
 Returns an instance of L<Mojo::Redis::Cursor> with
 L<Mojo::Redis::Cursor/command> set to the arguments passed. See
@@ -225,10 +253,10 @@ L<Mojo::Redis::Cursor/new>. for possible commands.
 
 =head2 new
 
-  $self = Mojo::Redis->new("redis://localhost:6379/1");
-  $self = Mojo::Redis->new(Mojo::URL->new->host("/tmp/redis.sock"));
-  $self = Mojo::Redis->new(\%attrs);
-  $self = Mojo::Redis->new(%attrs);
+  $redis = Mojo::Redis->new("redis://localhost:6379/1");
+  $redis = Mojo::Redis->new(Mojo::URL->new->host("/tmp/redis.sock"));
+  $redis = Mojo::Redis->new(\%attrs);
+  $redis = Mojo::Redis->new(%attrs);
 
 Object constructor. Can coerce a string into a L<Mojo::URL> and set L</url>
 if present.
